cmd

package
v1.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 29, 2025 License: Apache-2.0 Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func ReadConfig added in v1.3.0

func ReadConfig(ilog *backend.ILog) func(next http.Handler) http.Handler

ReadConfig is a go-chi middleware that reads a fresh config and adds it to the request context

Types

This section is empty.

Jump to